<?php

/**
 * @file
 * The primary PHP file for the eStore theme.
 */

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;

/**
 * Implements hook_form_system_theme_settings_alter().
 */
function estore_form_system_theme_settings_alter(&$form, FormStateInterface $form_state) {
  // Lock Fluid container option in the General Bootstrap theme settings.
  $form['general']['container']['fluid_container']['#default_value'] = 1;
  $form['general']['container']['fluid_container']['#disabled'] = TRUE;
  $form['general']['container']['fluid_container']['#description'] = t('eStore theme works with fluid container only.');
 $estore_regions = Url::fromRoute('block.admin_demo', ['theme' => 'estore']);
  $project_link = Link::fromTextAndUrl(t('eStore Regions'), $estore_regions);

  // Footer copyrights settings.
  $form['estore_settings'] = [
    '#weight' => -20,
    '#type' => 'container',
  ];
  $form['estore_settings']['header'] = [
    '#type' => 'markup',
    '#markup' => '<h2><small>'.t('eStore Settings').'</small></h2><ul><li>'.t('Overview of @regions that are availble for general block placment.', ['@regions'=>$project_link->toString()]).'</li></ul>',
  ];

  $form['estore_settings']['header_settings'] = [
    '#type' => 'fieldset',
    '#title' => t('eStore Header'),
    '#field_prefix' => t('Leave any of the inputs blank if you do not want item to be shown in header.'),
  ];
  $form['estore_settings']['header_settings']['header_email'] = [
    '#type' => 'email',
    '#title' => t('Email'),
    '#default_value' => theme_get_setting('header_email'),
  ];
  $form['estore_settings']['header_settings']['header_phone'] = [
    '#type' => 'textfield',
    '#title' => t('Phone'),
    '#default_value' => theme_get_setting('header_phone'),
  ];
  $form['estore_settings']['header_settings']['header_location'] = [
    '#type' => 'textfield',
    '#title' => t('Location'),
    '#default_value' => theme_get_setting('header_location'),
  ];
  $form['estore_settings']['header_settings']['header_shop_opens'] = [
    '#type' => 'textfield',
    '#title' => t('Shop opens'),
    '#default_value' => theme_get_setting('header_shop_opens'),
  ];

  $form['estore_settings']['copyright_text'] = [
    '#type' => 'textfield',
    '#title' => t('Footer Copyright Notice'),
    '#default_value' => theme_get_setting('copyright_text'),
    '#description' => t('Use @year placeholder for define current year.'),
  ];
  $form['estore_settings']['display_theme_credits'] = [
    '#type' => 'checkbox',
    '#title' => t('Display <q>Built by OPTASY</q> theme credits'),
    '#default_value' => theme_get_setting('display_theme_credits'),
  ];

  $message = t('Do you need help to customize this theme? We can help!
<ul>
<li>web: <a href="@url">https://www.optasy.com</a></li>
<li>e-mail: <a href="mailto:@email">contact@optasy.com</a></li>
<li>phone: <a href="tel:14162432431">(416) 243-2431 (Canada)</a></li>
</ul>',
    ['@url' => 'https://www.optasy.com', '@email' => 'contact@optasy.com']
  );
  \Drupal::messenger()->addMessage($message);
}
